#include "tpg300.h"

#include "send_receive.cpp" // Fonctions pour envoyer et recevoir
#include "fonctions_dialogues.cpp" // Fonctions de dialogue avec le TPG300

TPG300::TPG300(QWidget *parent) : QMainWindow(parent)
{
  ui.setupUi(this); // chargement de l'interface graphique

  port = NULL; // initialisation du port serie

  // creation du thread qui met a jour les valeurs
  thread.pt = this; // on donne le pointeur vers TPG300
  thread.start();

}


/////////////////////////////////////////////
// Configuration de la connexion RS232
/////////////////////////////////////////////
void TPG300::on_pushButton_1_1_clicked()
{
  // on affiche la fenetre
  fenetre_rs232.show();
}

/////////////////////////////////////////////
// Configuration de PARAMETRES
/////////////////////////////////////////////
void TPG300::on_pushButton_1_2_clicked()
{
  // on affiche la fenetre
  fenetre_parametres.show();
}

/////////////////////////////////////////////
// Connexion a l'appareil
/////////////////////////////////////////////
void TPG300::on_pushButton_1_3_clicked()
{
  // on efface le moniteur
  ui.textEdit_2_1->clear();


  // affiche sur le Moniteur que l'on a appuye sur le bouton connexion
  affichage_moniteur("Ouverture du port de communication");

  int erreur;
  // on configure le port de communication
  erreur = fenetre_rs232.connexion(port); // permet de se connecter a l'appareil

  if(erreur == -1)
  {
    affichage_moniteur("==> Erreur de connexion");
    thread.etat = 0;
    return;
  }
  else
  {
    port = (QextSerialPort *) erreur;
  }

  // on vide la file d'attente
  receive_rs232_rapide();

  ui.lineEdit_1_8->setText("0"); // nombre de cycles de mesures
  nb_cycles = 0; // initialisation a 0

  QDateTime date = QDateTime::currentDateTime();
  date_init = date;

  ui.lineEdit_1_5->setText(date.toString( "dd/MM/yyyy") ); // Date de dpart
  ui.lineEdit_1_6->setText(date.toString( "HH:mm:ss") ); // Heure de dpart
  nom_file = "data/data_VISCOVACVM212_" + date.toString( "yyyy-MM-dd_HH-mm-ss") + ".txt";
  ui.textEdit_1_1->insertPlainText( "./" + nom_file + "\n" ); // Nom du fichier d'enregistrement
  ui.textEdit_1_1->insertPlainText( "./data/data_VISCOVACVM212_current.txt" ); // Nom du fichier d'enregistrement
  ui.lineEdit_1_7->setText( date.toString( "dd/MM/yyyy - HH:mm:ss") );

  // On complte le fichier de mesures
  QFile file;
  file.setFileName("data/data_VISCOVACVM212_" + date.toString( "yyyy-MM-dd_HH-mm-ss") + ".txt");
  file.open(QIODevice::Append | QIODevice::Text );
  QTextStream out(&file);

  affichage_moniteur("Date et heure de dpart ==> " + date.toString( "dd/MM/yyyy - HH:mm:ss") );
  out << "Date et heure de dpart : " << date.toString( "dd/MM/yyyy - HH:mm:ss") << endl;

  int i=0;

  affichage_moniteur("");
  out << endl;

////////////////////////////////////////////////////////

  affichage_moniteur("1 - Paramtres individuels");
  out << "1 - Paramtres individuels" << endl;

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Programmation de l'unit d'affichage ==> ");
  out << "Unit d'affichage : " << endl;
  QString display;
  for(i = 1 ; i < 17 ; i++)
  {
    display = fctdisplay(i);
    affichage_moniteur(display);
    out << display << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Temps de messure ==> " );
  out << "Temps de messure : " << endl;
  QString mtime;
  for(i = 1 ; i < 17 ; i++)
  {
    mtime = fctmtime(i);
    affichage_moniteur(mtime);
    out << mtime << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Temps de messure ==> ");
  out << "Temps de messure : " << endl;
  QString offset;
  for(i = 1 ; i < 17 ; i++)
  {
    offset = fctoffset(i);
    affichage_moniteur(offset);
    out << offset << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Temprature d'affichage ==> ");
  out << "Temprature d'affichage : " << endl;
  QString temp;
  for(i = 1 ; i < 17 ; i++)
  {
    temp = fcttemp(i);
    affichage_moniteur(temp);
    out << temp << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Masse molaire relative ==> ");
  out << "Masse molaire relative : " << endl;
  QString molwt;
  for(i = 1 ; i < 17 ; i++)
  {
    molwt = fctmolwt(i);
    affichage_moniteur(molwt);
    out << molwt << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Viscosit ==> ");
  out << "Viscosit : " << endl;
  QString visc;
  for(i = 1 ; i < 17 ; i++)
  {
    visc = fctvisc(i);
    affichage_moniteur(visc);
    out << visc << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Sigma ==> ");
  out << "Sigma : " << endl;
  QString sigma;
  for(i = 1 ; i < 17 ; i++)
  {
    sigma = fctsigma(i);
    affichage_moniteur(sigma);
    out << sigma << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Densit du matriau de la boule ==> ");
  out << "Densit du matriau de la boule : " << endl;
  QString bdens;
  for(i = 1 ; i < 17 ; i++)
  {
    bdens = fctbdens(i);
    affichage_moniteur(bdens);
    out << bdens << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Diamtre de la boule ==> ");
  out << "Diamtre de la boule : " << endl;
  QString bdiam;
  for(i = 1 ; i < 17 ; i++)
  {
    bdiam = fctbdiam(i);
    affichage_moniteur(bdiam);
    out << bdiam << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("CDIAM ==> ");
  out << "CDIAM : " << endl;
  QString cdiam;
  for(i = 1 ; i < 17 ; i++)
  {
    cdiam = fctcdiam(i);
    affichage_moniteur(cdiam);
    out << cdiam << endl;
  }

  affichage_moniteur("");
  out << endl;


  affichage_moniteur("Mode de travail par point de commutation ==> ");
  out << "Mode de travail par point de commutation : " << endl;
  QString limits;
  for(i = 1 ; i < 17 ; i++)
  {
  limits = fctlimits(i);
  affichage_moniteur(limits);
  out << limits << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Point de commutation LOLIM ==> ");
  out << "Point de commutation LOLIM : " << endl;
  QString lolim;
  for(i = 1 ; i < 17 ; i++)
  {
    lolim = fctlolim(i);
    affichage_moniteur(lolim);
    out << lolim << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Point de commutation UPLIM ==> ");
  out << "Point de commutation UPLIM : " << endl;
  QString uplim;
  for(i = 1 ; i < 17 ; i++)
  {
    uplim = fctuplim(i);
    affichage_moniteur(uplim);
    out << uplim << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Sortie analogique ==> ");
  out << "Sortie analogique : " << endl;
  QString output;
  for(i = 1 ; i < 17 ; i++)
  {
    output = fctoutput(i);
    affichage_moniteur(output);
    out << output << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Limite infrieure de la sortie analogique ==> ");
  out << "Limite infrieure de la sortie analogique : " << endl;
  QString zero;
  for(i = 1 ; i < 17 ; i++)
  {
    zero = fctzero(i);
    affichage_moniteur(zero);
    out << zero << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Limite suprieure de la sortie analogique ==> ");
  out << "Limite suprieure de la sortie analogique : " << endl;
  QString fscal;
  for(i = 1 ; i < 17 ; i++)
  {
    fscal = fctfscal(i);
    affichage_moniteur(fscal);
    out << fscal << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Mode de travail de l'imprimante ==> ");
  out << "Mode de travail de l'imprimante : " << endl;
  QString printer;
  for(i = 1 ; i < 17 ; i++)
  {
    printer = fctprinter(i);
    affichage_moniteur(printer);
    out << printer << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("INTVL ==> ");
  out << "INTVL : " << endl;
  QString intvl;
  for(i = 1 ; i < 17 ; i++)
  {
    intvl = fctintvl(i);
    affichage_moniteur(intvl);
    out << intvl << endl;
  }

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Nombre de valeurs mesures par cycle de travail sur l'imprimante ==> ");
  out << "Nombre de valeurs mesures par cycle de travail sur l'imprimante : " << endl;
  QString sampl;
  for(i = 1 ; i < 17 ; i++)
  {
    sampl = fctsampl(i);
    affichage_moniteur(sampl);
    out << sampl << endl;
  }

  affichage_moniteur("");
  out << endl;

////////////////////////////////////////////////////////

  affichage_moniteur("2 - Jeu de paramtres");
  out << "2 - Jeu de paramtres" << endl;

  affichage_moniteur("");
  out << endl;

  affichage_moniteur("Jeu de paramtres en clair ==> ");
  out << "Jeu de paramtres  en clair : " << endl;
  QString par;
  for(i = 1 ; i < 11 ; i++)
  {
    par = fctpar(i);
    affichage_moniteur(par);
    out << par << endl;
  }

  affichage_moniteur("");
  out << endl;  

  affichage_moniteur("Jeu de paramtres en cod ==> ");
  out << "Jeu de paramtres  en cod : " << endl;
  QString cod;
  for(i = 1 ; i < 11 ; i++)
  {
  cod = fctcod(i);
  affichage_moniteur(cod);
  out << cod << endl;
  }

  affichage_moniteur("");
  out << endl;

////////////////////////////////////////////////////////

  affichage_moniteur("3 - Paramtres globaux");
  out << "3 - Paramtres globaux" << endl;

  affichage_moniteur("");
  out << endl;

  QString image;
  image = fctimage();
  affichage_moniteur("Sens du mouvement de l'imprimante ==> " + image);
  out << "Sens du mouvement de l'imprimante : " << image << endl;

  affichage_moniteur("");
  out << endl;

  QString automatic;
  automatic = fctautomatic();
  affichage_moniteur("Automatisme de la relance de l'entranement ==> " + automatic);
  out << "Automatisme de la relance de l'entranement : " << automatic << endl;

  affichage_moniteur("");
  out << endl;

  QString date2;
  date2 = fctdate();
  affichage_moniteur("Date ==> " + date2);
  out << "Date : " << date2 << endl;

  affichage_moniteur("");
  out << endl;

  QString time2;
  time2 = fcttime();
  affichage_moniteur("Heure ==> " + time2);
  out << "Heure : " << time2 << endl;

  affichage_moniteur("");
  out << endl;


////////////////////////////////////////////////////////

  affichage_moniteur("4 - Contrle de la mesure");
  out << "4 - Contrle de la mesure" << endl;

  affichage_moniteur("");
  out << endl;

  QString run;
  run = fctrun();
  affichage_moniteur("Numro indicatif du programme en service ==> " + run);
  out << "Numro indicatif du programme en service : " << run << endl;

  affichage_moniteur("");
  out << endl;

  QString stop;
  stop = fctstop();
  affichage_moniteur("Opration de freinage termine ==> " + stop);
  out << "Opration de freinage termine : " << stop << endl;

  affichage_moniteur("");
  out << endl;

  QString smh;
  smh = fctsmh();
  affichage_moniteur("Etat moment du rsultat de la mesure ==> " + smh);
  out << "Etat moment du rsultat de la mesure : " << smh << endl;

  affichage_moniteur("");
  out << endl;

////////////////////////////////////////////////////////

  affichage_moniteur("5 - Valeur mesure / grandeurs auxiliaires");
  out << "5 - Valeur mesure / grandeurs auxiliaires" << endl;

  affichage_moniteur("");
  out << endl;

  QString val;
  val = fctval();
  affichage_moniteur("Valeur mesure ==> " + val);
  out << "Valeur mesure : " << val << endl;

  affichage_moniteur("");
  out << endl;

  QString frq;
  frq = fctfrq();
  affichage_moniteur("Frquence du rotor ==> " + frq);
  out << "Frquence du rotor : " << frq << endl;

  affichage_moniteur("");
  out << endl;

  QString signalscattering;
  signalscattering = fctsignalscattering();
  affichage_moniteur("Dispersion des temps de rvolution de la boule ==> " + signalscattering);
  out << "Dispersion des temps de rvolution de la boule : " << signalscattering << endl;

  affichage_moniteur("");
  out << endl;

  QString amt;
  amt = fctamt();
  affichage_moniteur("Temps de mesure actuel ==> " + amt);
  out << "Temps de mesure actuel : " << amt << endl;

  affichage_moniteur("");
  out << endl;



////////////////////////////////////////////////////////

  affichage_moniteur("6 - Imprimante");
  out << "6 - Imprimante" << endl;

  affichage_moniteur("");
  out << endl;

  QString prs;
  prs = fctprs();
  affichage_moniteur("Etat imprimante ==> " + prs);
  out << "Etat imprimante : " << prs << endl;

  affichage_moniteur("");
  out << endl;

////////////////////////////////////////////////////////

  affichage_moniteur("7 - Etat du systme");
  out << "7 - Etat du systme" << endl;

  affichage_moniteur("");
  out << endl;

  QString sts;
  sts = fctsts();
  affichage_moniteur("Statut momentan de l'appareil ==> " + sts);
  out << "Statut momentan de l'appareil : " << sts << endl;

  affichage_moniteur("");
  out << endl;

  QString error;
  error = fcterror();
  affichage_moniteur("Numro d'erreur ==> " + error);
  out << "Numro d'erreur : " << error << endl;

  affichage_moniteur("");
  out << endl;

////////////////////////////////////////////////////////

  affichage_moniteur("8 - Interface");
  out << "8 - Interface" << endl;

  affichage_moniteur("");
  out << endl;

  QString srq;
  srq = fctsrq();
  affichage_moniteur("Condition pour que le bit SQR de l'octet statut ait la valeur 1 ==> " + srq);
  out << "Condition pour que le bit SQR de l'octet statut ait la valeur 1 : " << srq << endl;

  affichage_moniteur("");
  out << endl;

////////////////////////////////////////////////////////



  QString get_pressa1 = fctval();
  ui.lineEdit_1_1->setText(get_pressa1 ); 

  out << endl;
  out << endl;

  out << "Date et heure de la mesure" << "\x09" << "Temps coul (s)" << "\x09" << "Pression" << endl;
  out << date.toString( "dd/MM/yyyy HH:mm:ss") << "\x09" << "0" << "\x09" << get_pressa1 << endl;
  
  file.close();

  // on enregistre les donnees dans le fichier courant
  // On complte le fichier de mesures
  QFile file_current;
  file.setFileName("data/data_VISCOVACVM212_current.txt");
  if( file.exists() )
    file.remove();
  file.open(QIODevice::Append | QIODevice::Text );
  QTextStream out_current(&file);

  out_current << "Date et heure de la mesure" << "\x09" << ":" << "\x09" << date.toString( "dd/MM/yyyy HH:mm:ss") << endl;
  out_current << "Pression" << "\x09" << ":" << "\x09" << get_pressa1 << endl;

  file_current.close();

  thread.etat = 1; // demarrage des mesures du thread
}



/////////////////////////////////////////////
// Affichage sur le moniteur
void TPG300::affichage_moniteur(QString la_commande)
{
  ui.textEdit_2_1->insertPlainText( la_commande.toLatin1() + "\n" ); 
}


/////////////////////////////////////////////
// Mesure des pressions
/////////////////////////////////////////////
void TPG300::mesure(void)
{

  nb_cycles++; // ajout d'un cycle
  ui.lineEdit_1_8->setText(QString::number(nb_cycles)); // nombre de cycles de mesures

  QDateTime date = QDateTime::currentDateTime();
  int temps_ecoule = date_init.secsTo(date);

  // on fait les mesures de pression
  QString get_pressa1 = fctval();

  // on affiche les resultats
  ui.lineEdit_1_1->setText(get_pressa1 ); 

  // on affiche l'heure
  ui.lineEdit_1_7->setText( date.toString( "dd/MM/yyyy - HH:mm:ss") );

  // On complte le fichier de mesures
  QFile file;
  file.setFileName(nom_file);
  file.open(QIODevice::Append | QIODevice::Text );
  QTextStream out(&file);
  out << date.toString( "dd/MM/yyyy HH:mm:ss") << "\x09" << temps_ecoule << "\x09" << get_pressa1 << endl;
  file.close();

  // on enregistre les donnees dans le fichier courant
  QFile file_current;
  file.setFileName("data/data_VISCOVACVM212_current.txt");
  if( file.exists() )
    file.remove();
  file.open(QIODevice::Append | QIODevice::Text );
  QTextStream out_current(&file);
  out_current << "Date et heure de la mesure" << "\x09" << ":" << "\x09" << date.toString( "dd/MM/yyyy HH:mm:ss") << endl;
  out_current << "Pression" << "\x09" << ":" << "\x09" << get_pressa1 << endl;

  file_current.close();

}
