#ifndef TPG300_H
#define TPG300_H

#include <QWidget>
#include <QtGui>

#include <qextserialport.h> // gestion des connexions RS232

#include "ui_tpg300.h" // interface graphique
#include "fenetre_rs232.h" // fenetre de configuration RS232
#include "fenetre_parametres.h" // fenetre de configuration de la mesure
#include "threadtpg300.h" // gestion du thread pour les mesures

class TPG300 : public QMainWindow
{
  Q_OBJECT

// variables et fonctions
public:
  TPG300(QWidget *parent = 0); // constructeur

  Ui::TPG300 ui; // interface graphique principale
  RS232 fenetre_rs232; // fenetre pour configurer la connexion RS232
  PARAMETRES fenetre_parametres; // fenetre pour configurer la mesure

  QextSerialPort *port; // sert a communiquer par le port serie

  RenderThread thread; // le thread qui lit les donnees de mesure


  void affichage_moniteur(QString la_commande); // permet d'afficher sur le moniteur

  // envoi et reception
  int send_rs232(QString la_commande); // envoyer vers l'appareil
  QString receive_rs232(void); // recevoir une ligne de l'appareil
  QString receive_rs232_rapide(void); // vider les lignes de reception de l'appareil
  void mesure(void); // On realise une mesure des pressions

  // les fonctions de dialogue

  // 1 - parametres individuels
  QString fctdisplay(int nn); // VISCOVAC 212 Display DIS
  QString fctmtime(int nn); // VISCOVAC 212 MTIME MTI
  QString fctoffset(int nn); // VISCOVAC 212 OFFSET OFS
  QString fcttemp(int nn); // VISCOVAC 212 TEMP TEM
  QString fctmolwt(int nn); // VISCOVAC 212 MOLWT MOL
  QString fctvisc(int nn); // VISCOVAC 212 VISC VIS
  QString fctsigma(int nn); // VISCOVAC 212 SIGMA SIG
  QString fctbdens(int nn); // VISCOVAC 212 BDENS BDE
  QString fctbdiam(int nn); // VISCOVAC 212 BDIAM BDI
  QString fctcdiam(int nn); // VISCOVAC 212 CDIAM CDI
  QString fctlimits(int nn); // VISCOVAC 212 LIMITS LIM
  QString fctlolim(int nn); // VISCOVAC 212 LOLIM LOL
  QString fctuplim(int nn); // VISCOVAC 212 UPLIM UPL
  QString fctoutput(int nn); // VISCOVAC 212 OUTPUT ANO
  QString fctzero(int nn); // VISCOVAC 212 ZERO ZER
  QString fctfscal(int nn); // VISCOVAC 212 FSCAL FSC
  QString fctprinter(int nn); // VISCOVAC 212 PRINTER PRI
  QString fctintvl(int nn); // VISCOVAC 212 INTVL INT
  QString fctsampl(int nn); // VISCOVAC 212 SAMPL SAM

  // 2 - jeu de parametres
  QString fctpar(int nn); // VISCOVAC 212 PAR PAR
  QString fctcod(int nn); // VISCOVAC 212 COD COD
  // INI ==> uniquement en criture

  // 3 - parametres globaux
  QString fctimage(void); // VISCOVAC 212 IMAGE IMA
  QString fctautomatic(void); // VISCOVAC 212 AUTOMATIC AUT
  QString fctdate(void); // VISCOVAC 212 DATE DAT
  QString fcttime(void); // VISCOVAC 212 TIME TIM

  // 4 - controle de la mesure
  QString fctrun(void); // VISCOVAC 212 RUN RUN
  QString fctstop(void); // VISCOVAC 212 STOP STP
  QString fctsmh(void); // VISCOVAC 212 SMH SMH

  // 5 - valeur mesuree / grandeurs auxiliaires
  QString fctval(void); // VISCOVAC 212 VAL VAL  
  QString fctfrq(void); // VISCOVAC 212 FRQ FRQ
  QString fctsignalscattering(void); // VISCOVAC 212 SIGNAL SCATTERING SSC  
  QString fctamt(void); // VISCOVAC 212 AMT AMT

  // 6 - imprimante
  QString fctprs(void); // VISCOVAC 212 PRS PRS

  // 7 - etat systeme
  QString fctsts(void); // VISCOVAC 212 STS STS
  QString fcterror(void); // VISCOVAC 212 ERROR ERR

  // 8 - interface
  // ESQ ==> ecriture seulement
  QString fctsrq(void); // VISCOVAC 212 SRQ SRQ
  // GTL ==> ecriture seulement
  // LLO ==> ecriture seulement


  QString nom_file; // nom du fichier de stockage des donnees
  QDateTime date_init; // heure de debut
  int nb_cycles; // nombre de cycles de mesures

// les elements du UI
public slots:
  void on_pushButton_1_1_clicked();  // configuration RS232
  void on_pushButton_1_2_clicked();  // configuration paramtres
  void on_pushButton_1_3_clicked();  // connexion a l'appareil

};

#endif
